@@ -83,7 +83,9 @@ public class <%=data.moduleName%>Controller {
                                    var fieldNameUpper = data.firstUpper(field);
                                    var idType = data.moduleDefine['id'].type;
                                    if(refer.module==='user'){%>
-                              item.setUser(userService.obtainCurrentUser());
+                                   User currentUser = userService.obtainCurrentUser();
+                                   if(null == currentUser){throw new RuntimeException("User not Login!"); };
+                                   item.set<%=fieldNameUpper%>(currentUser);
 
 
                                    <%continue;}%>
